==> kubernetes-model-admissionregistration-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingFluent<A extends ValidatingAdmissionPolicyBindingFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> withNewMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editOrNewMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ValidatingAdmissionPolicyBindingSpec getSpec();
  public ValidatingAdmissionPolicyBindingSpec buildSpec();
  public A withSpec(ValidatingAdmissionPolicyBindingSpec spec);
  public Boolean hasSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> withNewSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> withNewSpecLike(ValidatingAdmissionPolicyBindingSpec item);
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editOrNewSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editOrNewSpecLike(ValidatingAdmissionPolicyBindingSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ValidatingAdmissionPolicyBindingFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ValidatingAdmissionPolicyBindingSpecFluent<ValidatingAdmissionPolicyBindingFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingFluent<A extends ValidatingAdmissionPolicyBindingFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> withNewMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editOrNewMetadata();
  public ValidatingAdmissionPolicyBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ValidatingAdmissionPolicyBindingSpec getSpec();
  public ValidatingAdmissionPolicyBindingSpec buildSpec();
  public A withSpec(ValidatingAdmissionPolicyBindingSpec spec);
  public Boolean hasSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> withNewSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> withNewSpecLike(ValidatingAdmissionPolicyBindingSpec item);
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editOrNewSpec();
  public ValidatingAdmissionPolicyBindingFluent.SpecNested<A> editOrNewSpecLike(ValidatingAdmissionPolicyBindingSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ValidatingAdmissionPolicyBindingFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ValidatingAdmissionPolicyBindingSpecFluent<ValidatingAdmissionPolicyBindingFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
